@@ -22,6 +22,7 @@ from .literals import (
     CETypeType,
     CRAllocationStrategyType,
     CRTypeType,
+    CRUpdateAllocationStrategyType,
     DeviceCgroupPermissionType,
     EFSAuthorizationConfigIAMType,
     EFSTransitEncryptionType,
@@ -136,6 +137,7 @@ __all__ = (
     "UpdateComputeEnvironmentResponseTypeDef",
     "UpdateJobQueueRequestRequestTypeDef",
     "UpdateJobQueueResponseTypeDef",
+    "UpdatePolicyTypeDef",
     "UpdateSchedulingPolicyRequestRequestTypeDef",
     "VolumeTypeDef",
 )
@@ -204,13 +206,13 @@ _RequiredComputeEnvironmentDetailTypeDef = TypedDict(
     {
         "computeEnvironmentName": str,
         "computeEnvironmentArn": str,
-        "ecsClusterArn": str,
     },
 )
 _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
     "_OptionalComputeEnvironmentDetailTypeDef",
     {
         "unmanagedvCpus": int,
+        "ecsClusterArn": str,
         "tags": Dict[str, str],
         "type": CETypeType,
         "state": CEStateType,
@@ -218,6 +220,7 @@ _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
         "statusReason": str,
         "computeResources": "ComputeResourceTypeDef",
         "serviceRole": str,
+        "updatePolicy": "UpdatePolicyTypeDef",
     },
     total=False,
 )
@@ -279,6 +282,18 @@ ComputeResourceUpdateTypeDef = TypedDict(
         "desiredvCpus": int,
         "subnets": Sequence[str],
         "securityGroupIds": Sequence[str],
+        "allocationStrategy": CRUpdateAllocationStrategyType,
+        "instanceTypes": Sequence[str],
+        "ec2KeyPair": str,
+        "instanceRole": str,
+        "tags": Mapping[str, str],
+        "placementGroup": str,
+        "bidPercentage": int,
+        "launchTemplate": "LaunchTemplateSpecificationTypeDef",
+        "ec2Configuration": Sequence["Ec2ConfigurationTypeDef"],
+        "updateToLatestImageVersion": bool,
+        "type": CRTypeType,
+        "imageId": str,
     },
     total=False,
 )
@@ -1366,6 +1381,7 @@ _OptionalUpdateComputeEnvironmentRequestRequestTypeDef = TypedDict(
         "unmanagedvCpus": int,
         "computeResources": "ComputeResourceUpdateTypeDef",
         "serviceRole": str,
+        "updatePolicy": "UpdatePolicyTypeDef",
     },
     total=False,
 )
@@ -1420,6 +1436,15 @@ UpdateJobQueueResponseTypeDef = TypedDict(
     },
 )
 
+UpdatePolicyTypeDef = TypedDict(
+    "UpdatePolicyTypeDef",
+    {
+        "terminateJobsOnUpdate": bool,
+        "jobExecutionTimeoutMinutes": int,
+    },
+    total=False,
+)
+
 _RequiredUpdateSchedulingPolicyRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateSchedulingPolicyRequestRequestTypeDef",
     {
